CKEDITOR.plugins.setLang('youtube', 'tr', {
	button : 'Youtube Video Gömün (Embed)',
	title : 'Youtube Video',
	txtEmbed : 'Youtube gömülü kodu (embed) buraya yapıştırınız',
	txtUrl : 'Youtube linkinizi buraya yapıştırınız',
	txtWidth : 'Genişlik',
	txtHeight : 'Yükseklik',
	chkRelated : 'Önerilen videoları video bitiminde göster',
	txtStartAt : 'Video başlangıç anı (ss ya da dd:ss ya da ss:dd:ss)',
	chkPrivacy : 'Gizlilik modunu etkinleştir',
	chkOlderCode : 'Eski gömülü kodu (embed) kullan',
	chkAutoplay: 'Otomatik',
	chkControls: 'Oynatıcı kontrollerini göster',
	noCode : 'Gömülü kod (embed) veya url yapıştırmak zorundasınız',
	invalidEmbed : 'Verdiğiniz gömülü kod (embed) ile video bulunamadı',
	invalidUrl : 'Verdiğiniz linkte video bulunamadı',
	or : 'ya da',
	noWidth : 'Genişliği belirtmek zorundasınız',
	invalidWidth : 'Bir genişlik belirtin',
	noHeight : 'Yükseliği belirtmek zorundasınız',
	invalidHeight : 'Yükseklik belirtin',
	invalidTime : 'Başlangıç anını doğru girin, örneğin: 13 (13. saniye) ya da 12:25 (12. dakika 25. saniye) ya da 01.25.33 (1 saat 25 dakika 33 saniye)',
	txtResponsive : 'Responsive video'
});
